@@ -233,6 +233,35 @@
           throw new Error("Unknown Rails node type");
       }
     },
+    build_path_spec: function(route, wildcard) {
+      var left, right, type;
+
+      if (wildcard == null) {
+        wildcard = false;
+      }
+      type = route[0], left = route[1], right = route[2];
+      switch (type) {
+        case NodeTypes.GROUP:
+          return "(" + (this.build_path_spec(left)) + ")";
+        case NodeTypes.CAT:
+          return "" + (this.build_path_spec(left)) + (this.build_path_spec(right));
+        case NodeTypes.STAR:
+          return this.build_path_spec(left, true);
+        case NodeTypes.SYMBOL:
+          if (wildcard === true) {
+            return "" + (left[0] === '*' ? '' : '*') + left;
+          } else {
+            return ":" + left;
+          }
+          break;
+        case NodeTypes.SLASH:
+        case NodeTypes.DOT:
+        case NodeTypes.LITERAL:
+          return left;
+        default:
+          throw new Error("Unknown Rails node type");
+      }
+    },
     visit_globbing: function(route, parameters, optional) {
       var left, right, type, value;
 
@@ -263,6 +292,18 @@
       }
       return prefix;
     },
+    route: function(required_parts, optional_parts, route_spec) {
+      var path_fn;
+
+      path_fn = function() {
+        return Utils.build_path(required_parts, optional_parts, route_spec, arguments);
+      };
+      path_fn.required_params = required_parts;
+      path_fn.toString = function() {
+        return Utils.build_path_spec(route_spec);
+      };
+      return path_fn;
+    },
     _classToTypeCache: null,
     _classToType: function() {
       var name, _i, _len, _ref;
