@@ -150,8 +150,8 @@ describe JsRoutes, "compatibility with Rails"  do
   context "when jQuery is present" do
     before do
       evaljs("window.jQuery = {};")
-      jscontext[:parameterize] = lambda {|object| _value.to_param}
-      evaljs("window.jQuery.param = parameterize")
+      jscontext[:parameterizeFunc] = lambda {|object| _value.to_param}
+      evaljs("window.jQuery.param = parameterizeFunc")
     end
 
     shared_examples_for "serialization" do
@@ -177,6 +177,11 @@ describe JsRoutes, "compatibility with Rails"  do
       let(:_value) do
         nil
       end
+
+      before do
+        pending("This test is invalid for nil/null and jruby #{JRUBY_VERSION}") if defined?(JRUBY_VERSION) && '1.7.13' == JRUBY_VERSION
+      end
+
       it_should_behave_like 'serialization'
     end
   end
@@ -199,11 +204,17 @@ describe JsRoutes, "compatibility with Rails"  do
         expect(evaljs("Routes.thing_path(null, 5)")).to eq(routes.thing_path(nil, 5))
       end
 
+      # Fail for rails 4.2. Reason: https://github.com/rails/rails/issues/12178
       it "should treat undefined as non-given optional part" do
+        # TODO: remove me after release of rails 4.2.1 (change Appraisals to "~> 4.2.1")
+        pending("This test is invalid for rails 4.2. Reason: https://github.com/rails/rails/issues/12178") if [4, 2, 0] == [Rails::VERSION::MAJOR, Rails::VERSION::MINOR, Rails::VERSION::TINY]
         expect(evaljs("Routes.thing_path(5, {optional_id: undefined})")).to eq(routes.thing_path(5, :optional_id => nil))
       end
 
+      # Fail for rails 4.2. Reason: https://github.com/rails/rails/issues/12178
       it "should treat null as non-given optional part" do
+        # TODO: remove me after release of rails 4.2.1 (change Appraisals to "~> 4.2.1")
+        pending("This test is invalid for rails 4.2. Reason: https://github.com/rails/rails/issues/12178") if [4, 2, 0] == [Rails::VERSION::MAJOR, Rails::VERSION::MINOR, Rails::VERSION::TINY]
         expect(evaljs("Routes.thing_path(5, {optional_id: null})")).to eq(routes.thing_path(5, :optional_id => nil))
       end
     end
@@ -291,4 +302,32 @@ describe JsRoutes, "compatibility with Rails"  do
       end
     end
   end
+
+  context "when specs" do
+    it "should show inbox spec" do
+      expect(evaljs("Routes.inbox_path.toString()")).to eq('/inboxes/:id(.:format)')
+    end
+
+    it "should show inbox spec convert to string" do
+      expect(evaljs("'' + Routes.inbox_path")).to eq('/inboxes/:id(.:format)')
+    end
+
+    it "should show inbox message spec" do
+      expect(evaljs("Routes.inbox_message_path.toString()")).to eq('/inboxes/:inbox_id/messages/:id(.:format)')
+    end
+
+    it "should show inbox message spec convert to string" do
+      expect(evaljs("'' + Routes.inbox_message_path")).to eq('/inboxes/:inbox_id/messages/:id(.:format)')
+    end
+  end
+
+  context "when params" do
+    it "should show inbox spec" do
+      expect(evaljs("Routes.inbox_path.required_params").to_a).to eq(["id"])
+    end
+
+    it "should show inbox message spec" do
+      expect(evaljs("Routes.inbox_message_path.required_params").to_a).to eq(["inbox_id", "id"])
+    end
+  end
 end
