@@ -108,6 +108,12 @@ def draw_routes
 
     get '/привет' => "foo#foo", :as => :hello
     get '(/o/:organization)/search/:q' => "foo#foo", as: :search
+
+    resources :sessions, :only => [:new, :create, :destroy], :protocol => 'https'
+
+    get '/' => 'sso#login', host: 'sso.example.com', as: :sso
+
+    resources :portals, :port => 8080
   end
 
 end
